@@ -113,7 +113,8 @@ st_convex_hull = function(x) st_sfc(CPL_geom_op("convex_hull", st_geometry(x)))
 #' @name geos
 #' @export
 #' @examples 
-#' nc = st_read(system.file("gpkg/nc.gpkg", package="sf"), "nc.gpkg", crs = 4267)
+#' # nc = st_read(system.file("gpkg/nc.gpkg", package="sf"), "nc.gpkg", crs = 4267)
+#' nc = st_read(system.file("shape/nc.shp", package="sf"), "nc", crs = 4267)
 #' plot(st_union_cascaded(st_sfc(do.call(c, st_geometry(nc)))),col=0)
 st_union_cascaded = function(x) st_sfc(CPL_geom_op("union_cascaded", st_geometry(x)))
 
@@ -129,8 +130,12 @@ st_simplify = function(x, preserveTopology = FALSE, dTolerance = 0.0)
 #' @param bOnlyEdges logical; if TRUE, return lines, else return polygons
 #' @details requires GEOS version 3.4 or above
 # nocov start
-st_triangulate = function(x, dTolerance = 0.0, bOnlyEdges = FALSE)
-	st_sfc(CPL_geom_op("triangulate", st_geometry(x), dTolerance = dTolerance, bOnlyEdges = bOnlyEdges))
+st_triangulate = function(x, dTolerance = 0.0, bOnlyEdges = FALSE) {
+	if (CPL_gdal_version() >= "2.1.0")
+		st_sfc(CPL_geom_op("triangulate", st_geometry(x), dTolerance = dTolerance, bOnlyEdges = bOnlyEdges))
+	else
+		stop("for triangulate, GDAL version 2.1.0 is required")
+}
 # nocov end
 
 #' @name geos
