@@ -1,5 +1,6 @@
 library(sf)
-nc = st_read(system.file("gpkg/nc.gpkg", package="sf"), "nc.gpkg", crs = 4267)
+# nc = st_read(system.file("gpkg/nc.gpkg", package="sf"), "nc.gpkg", crs = 4267)
+nc = st_read(system.file("shape/nc.shp", package="sf"), "nc", crs = 4267)
 
 st_distance(nc[1:10,], nc[1:10,])
 
